/**
 * An interface for a roster holding the names of superheroes (or anyone, really).
 * Implementing classes will also implement a portion of the Set<String> interface.
 * 
 * @author Joel
 * @version Fa 2014
 */
public interface HeroSet
{
	/**
	 * Adds the specified hero to this set if it is not already present.
	 * @param hero The hero to be added
	 * @return true if this set did not already contain the specified hero
	 */
	public abstract boolean add(String hero);
	
	/**
	 * Removes all of the elements from this set. The set will be empty after this call returns.
	 */
	public abstract void clear();
	
	/**
	 * Returns true if this set contains the specified hero.
	 * @param hero The hero whose presence is to be tested
	 * @return true if this set contains the specified hero
	 */
	public abstract boolean contains(String hero);
	
	/**
	 * Returns true if this set contains no elements.
	 * @return true if this set contains no elements
	 */
	public abstract boolean isEmpty();
	
	/**
	 * Removes the specified hero from this set if it is present. Returns true if this set contained the hero (or equivalently, if this set changed as a result of the call). 
	 * (This set will not contain the element once the call returns.)
	 * @param hero The hero to be removed from the set, if present
	 * @return true if the set contained the specified element
	 */
	public abstract boolean remove(String hero);
	
	/**
	 * Returns the number of heroes in this set (its cardinality).
	 * @return the number of heroes in this set (its cardinality)
	 */
	public abstract int size();
	
	/**
	 * Returns the current load factor of the roster--the percentage of spaces in the roster that are filled.
	 * @return
	 */
	public abstract double getLoadFactor();
	
}
